pub enum ReadyOrNot<F: Future> {
Ready(F::Output),
Not(F),
}Expand description
This type holds a future that has been detached from a group.
Variants
Ready(F::Output)
If the future has run to completion, this variant holds the future’s output.
Not(F)
If the future has not yet run to completion, this variant holds the future.
Implementations
Sourceimpl<F: Future> ReadyOrNot<F>
impl<F: Future> ReadyOrNot<F>
Sourcepub async fn output(self) -> F::Output
pub async fn output(self) -> F::Output
A convenience method for retrieving the output of the future, either by driving the contained future to completion or by unwrapping the output value.
Note that this method does not drive the background futures of an async group. To drive the background
futures, use Group::detach_and_wait_for instead of detaching the future separately.